# Basic Data Strcutre Algorithms


## 1. Quick Sort
Quick Sort is a sorting algorithm, which is commonly used in computer science. 
Quick Sort is a divide and conquer algorithm. 

### Usage
```python
from hammuon.data_structure.quick_sort import quickSort

print(quickSort([8, 12, 55, -12]))
```

### Output
```bash
[-12, 8, 12, 55]
```

## 2. Bubble Sort
Bubble sort is a sorting algorithm that compares two adjacent
elements and swaps them until they are not in the intended order.

### Usage
```python
from hammuon.data_structure.bubble_sort import bubbleSort

print(bubbleSort([8, 12, 55, -12]))
```

### Output
```bash
[-12, 8, 12, 55]
```